@@ -1,10 +1,10 @@
 #' nlm_mosaicfield
 #'
-#' @description Create a mosaic random field neutral landscape model.
+#' @description Simulate a mosaic random field neutral landscape model.
 #'
-#' @param nCol [\code{numerical(1)}]\cr
+#' @param ncol [\code{numerical(1)}]\cr
 #' Number of columns for the raster.
-#' @param nRow  [\code{numerical(1)}]\cr
+#' @param nrow  [\code{numerical(1)}]\cr
 #' Number of rows for the raster.
 #' @param resolution  [\code{numerical(1)}]\cr
 #' Resolution of the raster.
@@ -30,11 +30,17 @@
 #' methodology and applications with R. CRC Press, 2015.
 #'
 #' @examples
-#' nlm_mosaicfield(nCol = 200,
-#'                 nRow = 200,
-#'                 n = NA,
-#'                 infinit = TRUE,
-#'                 collect = FALSE)
+#'
+#' # simulate mosaic random field
+#' mosaic_field <- nlm_mosaicfield(ncol = 100,
+#'                                 nrow = 200,
+#'                                 n = NA,
+#'                                 infinit = TRUE,
+#'                                 collect = FALSE)
+#' \dontrun{
+#' # visualize the NLM
+#' util_plot(mosaic_field)
+#' }
 #'
 #' @aliases nlm_mosaicfield
 #' @rdname nlm_mosaicfield
@@ -42,21 +48,21 @@
 #' @export
 
 
-nlm_mosaicfield <- function(nCol,
-                            nRow,
+nlm_mosaicfield <- function(ncol,
+                            nrow,
                             resolution  = 1,
                             n           = 20,
                             mosaic_mean = 0.5,
                             mosaic_sd   = 0.5,
                             collect     = FALSE,
                             infinit     = FALSE,
-                            rescale     = TRUE){
+                            rescale     = TRUE) {
 
   # Check function arguments ----
-  checkmate::assert_count(nCol, positive = TRUE)
-  checkmate::assert_count(nRow, positive = TRUE)
+  checkmate::assert_count(ncol, positive = TRUE)
+  checkmate::assert_count(nrow, positive = TRUE)
   checkmate::assert_numeric(resolution)
-  # checkmate::assert_count(n, positive = TRUE)
+  checkmate::assert_count(n, positive = TRUE, na.ok = TRUE)
   checkmate::assert_numeric(mosaic_mean)
   checkmate::assert_numeric(mosaic_sd)
   checkmate::assert_logical(collect)
@@ -66,12 +72,15 @@ nlm_mosaicfield <- function(nCol,
   mosaicfields_return <- list()
 
   if (!is.na(n)) {
-
-    mosaicfield_result <- spatstat::rMosaicField(spatstat::rpoislinetess(4),
-                                                 stats::rnorm,
-                                                 dimyx=c(nCol,nRow),
-                                                 rgenargs=list(mean=mosaic_mean,
-                                                               sd=mosaic_sd))
+    mosaicfield_result <- spatstat::rMosaicField(
+      spatstat::rpoislinetess(4),
+      stats::rnorm,
+      dimyx = c(nrow, ncol),
+      rgenargs = list(
+        mean = mosaic_mean,
+        sd = mosaic_sd
+      )
+    )
 
     if (isTRUE(collect)) {
       i <- 2
@@ -80,11 +89,15 @@ nlm_mosaicfield <- function(nCol,
     }
 
     for (i in 1:n) {
-      mosaicfield_n <- spatstat::rMosaicField(spatstat::rpoislinetess(4),
-                                              stats::rnorm,
-                                              dimyx=c(nCol,nRow),
-                                              rgenargs=list(mean=mosaic_mean,
-                                                            sd=mosaic_sd))
+      mosaicfield_n <- spatstat::rMosaicField(
+        spatstat::rpoislinetess(4),
+        stats::rnorm,
+        dimyx = c(nrow, ncol),
+        rgenargs = list(
+          mean = mosaic_mean,
+          sd = mosaic_sd
+        )
+      )
 
       mosaicfield_result <- mosaicfield_result + mosaicfield_n
 
@@ -100,10 +113,12 @@ nlm_mosaicfield <- function(nCol,
     sp::coordinates(mosaicfield_df) <- ~ x + y
     sp::gridded(mosaicfield_df) <- TRUE
     mosaicfield_raster <- raster::raster(mosaicfield_df)
-    raster::extent(mosaicfield_raster) <- c(0,
-                                            ncol(mosaicfield_raster)*resolution,
-                                            0,
-                                            nrow(mosaicfield_raster)*resolution)
+    raster::extent(mosaicfield_raster) <- c(
+      0,
+      ncol(mosaicfield_raster) * resolution,
+      0,
+      nrow(mosaicfield_raster) * resolution
+    )
 
     # Rescale values to 0-1
     if (rescale == TRUE) {
@@ -113,12 +128,9 @@ nlm_mosaicfield <- function(nCol,
     mosaicfields_return$mosaicfield_raster <- mosaicfield_raster
 
     if (isTRUE(collect)) {
-
-      names(mosaicfield_list) <- 1:length(mosaicfield_list)
+      names(mosaicfield_list) <- seq_along(mosaicfield_list)
       mosaicfield_list <- purrr::map(seq_along(mosaicfield_list), function(i) {
-
-        mosaicfield_list[[i]] <- mosaicfield_list[[i]]/sqrt(i)
-
+        mosaicfield_list[[i]] <- mosaicfield_list[[i]] / sqrt(i)
       })
 
       mosaicfield_list <- purrr::map(seq_along(mosaicfield_list), function(i) {
@@ -128,10 +140,12 @@ nlm_mosaicfield <- function(nCol,
         sp::coordinates(mosaicfield_list[[i]]) <- ~ x + y
         sp::gridded(mosaicfield_list[[i]]) <- TRUE
         mosaicfield_list[[i]] <- raster::raster(mosaicfield_list[[i]])
-        raster::extent(mosaicfield_list[[i]]) <- c(0,
-                                                   ncol(mosaicfield_list[[i]])*resolution,
-                                                   0,
-                                                   nrow(mosaicfield_list[[i]])*resolution)
+        raster::extent(mosaicfield_list[[i]]) <- c(
+          0,
+          ncol(mosaicfield_list[[i]]) * resolution,
+          0,
+          nrow(mosaicfield_list[[i]]) * resolution
+        )
 
         mosaicfield_list[[i]]
       })
@@ -146,16 +160,14 @@ nlm_mosaicfield <- function(nCol,
 
 
       mosaicfields_return$steps <- mosaicfields_brick
-
     }
-
-
   }
 
   if (isTRUE(infinit)) {
 
     # INFINITE STEPS:
-    X <- spatstat::rLGCP("exp", 4, var=1, scale=.2, saveLambda=TRUE)
+    X <- spatstat::rLGCP("exp", 4, var = 1, dimyx = c(nrow, ncol),
+                         scale = .2, saveLambda = TRUE)
     mosaicfield_inf <- RandomFields::log(attr(X, "Lambda"))
 
     # coerce spatstat image to raster and set proper resolution ----
@@ -163,10 +175,12 @@ nlm_mosaicfield <- function(nCol,
     sp::coordinates(mosaicfield_df) <- ~ x + y
     sp::gridded(mosaicfield_df) <- TRUE
     mosaicfield_raster <- raster::raster(mosaicfield_df)
-    raster::extent(mosaicfield_raster) <- c(0,
-                                            ncol(mosaicfield_raster)*resolution,
-                                            0,
-                                            nrow(mosaicfield_raster)*resolution)
+    raster::extent(mosaicfield_raster) <- c(
+      0,
+      ncol(mosaicfield_raster) * resolution,
+      0,
+      nrow(mosaicfield_raster) * resolution
+    )
 
     # Rescale values to 0-1
     if (rescale == TRUE) {
@@ -178,26 +192,9 @@ nlm_mosaicfield <- function(nCol,
   }
 
 
-  if(length(mosaicfields_return) == 1)  mosaicfields_return <- mosaicfields_return[[1]]
+  if (length(mosaicfields_return) == 1) {
+    mosaicfields_return <- mosaicfields_return[[1]]
+  }
 
   return(mosaicfields_return)
-
-
 }
-
-# TEST STUFF
-#
-# X <- runifpoint(2)
-# plot(dirichlet(X))
-# mosaicfield_result <- rMosaicField(dirichlet(X),
-#                                  rnorm, dimyx=c(nCol,nRow), rgenargs=list(mean=0.5, sd=0.5))
-#
-#
-#
-# for (i in 1:n) {
-#   mosaicfield_n <- rMosaicField(dirichlet(runifpoint(2)),
-#                               rnorm, dimyx=c(nCol,nRow), rgenargs=list(mean=0.5, sd=0.5))
-#   mosaicfield_result <- mosaicfield_result + mosaicfield_n
-#
-#   ### COLLECT STEPS IN LIST
-# }
