@@ -1,6 +1,6 @@
 #' Binarize continuous raster values
 #'
-#' @description Reclassify continuous raster values into binary map cells based upon given
+#' @description Classify continuous raster values into binary map cells based upon given
 #' break(s).
 #'
 #' @details Breaks are considered to be habitat percentages (p). If more than
@@ -11,7 +11,7 @@
 #' @param breaks a vector with one or more break percentages
 #'
 #'
-#' @return RasterBrick
+#' @return RasterLayer / RasterBrick
 #'
 #' @examples
 #' rndMap <- nlm_random(10, 10)
@@ -31,13 +31,27 @@ util_binarize <- function(x, breaks) {
   checkmate::assert_class(x, "RasterLayer")
   checkmate::assert_atomic_vector(breaks)
 
-  map.stack <- raster::stack()
-  for (i in seq_along(breaks)) {
-    map.stack <- raster::stack(map.stack,
-                       util_classify(x, c(breaks[i], 1 - breaks[i]), c("Habitat", "Matrix")))
+  if (length(breaks) > 1) {
+    map.stack <- raster::stack()
+    for (i in seq_along(breaks)) {
+      map.stack <- raster::stack(
+        map.stack,
+        util_classify(
+          x,
+          c(1 - breaks[i], breaks[i]),
+          c("Matrix", "Habitat")
+        )
+      )
+    }
+    names(map.stack) <- paste("p", breaks)
+    r <- raster::brick(map.stack)
+  } else {
+    r <- util_classify(
+      x,
+      c(1 - breaks, breaks),
+      c("Matrix", "Habitat")
+    )
   }
 
-  names(map.stack) <- paste("p ", breaks, sep = " ")
-  raster::brick(map.stack)
-
+  return(r)
 }
